sconce.models.layers package
============================

sconce.models.layers.convolution2d\_layer module
------------------------------------------------

.. automodule:: sconce.models.layers.convolution2d_layer
    :members:
    :undoc-members:
    :show-inheritance:

sconce.models.layers.fully\_connected\_layer module
---------------------------------------------------

.. automodule:: sconce.models.layers.fully_connected_layer
    :members:
    :undoc-members:
    :show-inheritance:
